@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
 """SunPy sample data files"""
-from __future__ import absolute_import
+from __future__ import absolute_import, division, print_function
 
-from os import remove
 import os.path
 from zipfile import ZipFile
-from urllib2 import URLError
 from shutil import move
 
 from astropy.utils.data import download_file
 
+from sunpy.extern import six
+from sunpy.extern.six.moves.urllib.error import URLError
+
 from sunpy.util.net import url_exists
 from sunpy import config
 
@@ -55,24 +56,27 @@ for key in _files:
     sample_files[key] = os.path.abspath(os.path.join(sampledata_dir, _files[key][0]))
 
 
-def download_sample_data(progress=True, overwrite=True):
+def download_sample_data(progress=True, overwrite=True, timeout=None):
     """
     Download the sample data.
 
     Parameters
     ----------
-    progress: bool
+    progress: `bool`
         Show a progress bar during download
-    overwrite: bool
+    overwrite: `bool`
         If exist overwrites the downloaded sample data.
+    timeout: `float`
+        The timeout in seconds. If `None` the default timeout is used from
+        `astropy.utils.data.Conf.remote_timeout`.
 
     Returns
     -------
     None
     """
     number_of_files_fetched = 0
-    print("Downloading sample files to " + sampledata_dir)
-    for file_name in _files.itervalues():
+    print("Downloading sample files to {}".format(sampledata_dir))
+    for file_name in six.itervalues(_files):
         if not overwrite:
             if os.path.isfile(os.path.join(sampledata_dir,
                                            file_name[0])):
@@ -82,14 +86,14 @@ def download_sample_data(progress=True, overwrite=True):
         for base_url in _base_urls:
             full_file_name = file_name[0] + file_name[1]
             if url_exists(os.path.join(base_url, full_file_name)):
-                f = download_file(os.path.join(base_url, full_file_name))
+                f = download_file(os.path.join(base_url, full_file_name), timeout=timeout)
                 real_name, ext = os.path.splitext(full_file_name)
 
                 if file_name[1] == '.zip':
-                    print("Unpacking: %s" % real_name)
+                    print("Unpacking: {}".format(real_name))
                     with ZipFile(f, 'r') as zip_file:
                         zip_file.extract(real_name, sampledata_dir)
-                    remove(f)
+                    os.remove(f)
                 else:
                     # move files to the data directory
                     move(f, os.path.join(sampledata_dir, file_name[0]))
@@ -97,5 +101,5 @@ def download_sample_data(progress=True, overwrite=True):
                 number_of_files_fetched += 1
                 break
 
-    if number_of_files_fetched < len(_files.keys()):
+    if number_of_files_fetched < len(list(_files.keys())):
         raise URLError("Could not download all samples files. Problem with accessing sample data servers.")
