@@ -2,14 +2,12 @@
 #
 # This module was developed with funding provided by
 # the Google Summer of Code (2013).
-
 from __future__ import absolute_import
 
 from time import strptime, mktime
 from datetime import datetime
 import fnmatch
 import os
-from itertools import imap
 
 from astropy.units import Unit, nm, equivalencies
 from sqlalchemy import Column, Integer, Float, String, DateTime, Boolean,\
@@ -20,8 +18,12 @@ from sqlalchemy.ext.declarative import declarative_base
 from sunpy.time import parse_time
 from sunpy.io import fits, file_tools as sunpy_filetools
 from sunpy.util import print_table
+from sunpy.extern.six.moves import map
+from sunpy.extern import six
 
 from sunpy import config
+
+
 TIME_FORMAT = config.get("general", "time_format")
 
 __all__ = [
@@ -110,6 +112,9 @@ class FitsHeaderEntry(Base):
             self.key == other.key and
             self.value == other.value)
 
+    def __hash__(self):
+        return super(FitsHeaderEntry, self).__hash__()
+
     def __ne__(self, other):
         return not (self == other)
 
@@ -136,6 +141,13 @@ class FitsKeyComment(Base):
             self.key == other.key and
             self.value == other.value)
 
+    def __lt__(self, other):
+        return ('{0}, {1}'.format(self.key, self.value) <
+                '{0}, {1}'.format(other.key, other.value))
+
+    def __hash__(self):
+        return super(FitsKeyComment, self).__hash__()
+
     def __ne__(self, other):
         return not (self == other)
 
@@ -155,6 +167,9 @@ class Tag(Base):
     def __eq__(self, other):
         return self.name == other.name
 
+    def __hash__(self):
+        return super(Tag, self).__hash__()
+
     def __ne__(self, other):
         return not (self == other)
 
@@ -347,6 +362,9 @@ class DatabaseEntry(Base):
             self.fits_header_entries == other.fits_header_entries and
             self.tags == other.tags)
 
+    def __hash__(self):
+        return super(DatabaseEntry, self).__hash__()
+
     def __ne__(self, other):  # pragma: no cover
         return not (self == other)
 
@@ -466,20 +484,20 @@ def entries_from_file(file, default_waveunit=None):
 
     """
     headers = fits.get_header(file)
-    if isinstance(file, (str, unicode)):
+    if isinstance(file, (str, six.text_type)):
         filename = file
     else:
         filename = getattr(file, 'name', None)
     for header in headers:
         entry = DatabaseEntry(path=filename)
-        for key, value in header.iteritems():
+        for key, value in six.iteritems(header):
             # Yes, it is possible to have an empty key in a FITS file.
             # Example: sunpy.data.sample.EIT_195_IMAGE
             # Don't ask me why this could be a good idea.
             if key == '':
                 value = str(value)
             elif key == 'KEYCOMMENTS':
-                for k, v in value.iteritems():
+                for k, v in six.iteritems(value):
                     entry.fits_key_comments.append(FitsKeyComment(k, v))
                 continue
             entry.fits_header_entries.append(FitsHeaderEntry(key, value))
@@ -549,7 +567,6 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
 
     Examples
     --------
-    >>> from pprint import pprint
     >>> from sunpy.data.test import rootdir as fitsdir
     >>> from sunpy.database.tables import entries_from_dir
     >>> entries = list(entries_from_dir(fitsdir, default_waveunit='angstrom'))
@@ -559,14 +576,6 @@ def entries_from_dir(fitsdir, recursive=False, pattern='*',
     >>> entries = list(entries_from_dir(fitsdir, True, default_waveunit='angstrom'))
     >>> len(entries)
     59
-    >>> # print the first 5 items of the FITS header of the first found file
-    >>> first_entry, filename = entries[0]
-    >>> pprint(first_entry.fits_header_entries[:5])
-    [<FitsHeaderEntry(id None, key 'SIMPLE', value True)>,
-     <FitsHeaderEntry(id None, key 'BITPIX', value -64)>,
-     <FitsHeaderEntry(id None, key 'NAXIS', value 2)>,
-     <FitsHeaderEntry(id None, key 'NAXIS1', value 128)>,
-     <FitsHeaderEntry(id None, key 'NAXIS2', value 128)>]
 
     """
     for dirpath, dirnames, filenames in os.walk(fitsdir):
@@ -616,7 +625,7 @@ def display_entries(database_entries, columns, sort=False):
             if col == 'starred':
                 row.append('Yes' if entry.starred else 'No')
             elif col == 'tags':
-                row.append(', '.join(imap(str, entry.tags)) or 'N/A')
+                row.append(', '.join(map(str, entry.tags)) or 'N/A')
             # do not display microseconds in datetime columns
             elif col in (
                     'observation_time_start',
