@@ -1,9 +1,10 @@
 """Image resampling methods"""
-from __future__ import absolute_import
+from __future__ import absolute_import, division, print_function
 
 import numpy as np
 import scipy.interpolate
 import scipy.ndimage
+from sunpy.extern.six.moves import range
 
 __all__ = ['resample', 'reshape_image_to_4d_superpixel']
 
@@ -99,8 +100,8 @@ def _resample_nearest_linear(orig, dimensions, method, offset, m1):
 
     new_data = mint(dimlist[-1])
 
-    trorder = [orig.ndim - 1] + range(orig.ndim - 1)
-    for i in xrange(orig.ndim - 2, -1, -1):
+    trorder = [orig.ndim - 1] + list(range(orig.ndim - 1))
+    for i in range(orig.ndim - 2, -1, -1):
         new_data = new_data.transpose(trorder)
 
         mint = scipy.interpolate.interp1d(old_coords[i], new_data,
@@ -119,7 +120,7 @@ def _resample_neighbor(orig, dimensions, offset, m1):
 
     dimlist = []
 
-    for i in xrange(orig.ndim):
+    for i in range(orig.ndim):
         base = np.indices(dimensions)[i]
         dimlist.append((orig.shape[i] - m1) / (dimensions[i] - m1) *
                        (base + offset) - offset)
@@ -137,7 +138,7 @@ def _resample_spline(orig, dimensions, offset, m1):
     nslices = [slice(0, j) for j in list(dimensions)]
     newcoords = np.mgrid[nslices]
 
-    newcoords_dims = range(np.rank(newcoords))
+    newcoords_dims = list(range(np.rank(newcoords)))
 
     #make first index last
     newcoords_dims.append(newcoords_dims.pop(0))
@@ -154,7 +155,7 @@ def _resample_spline(orig, dimensions, offset, m1):
     return scipy.ndimage.map_coordinates(orig, newcoords)
 
 
-def reshape_image_to_4d_superpixel(img, dimensions):
+def reshape_image_to_4d_superpixel(img, dimensions, offset):
     """Re-shape the two dimension input image into a a four dimensional
     array whose first and third dimensions express the number of original
     pixels in the x and y directions that form one superpixel. The reshaping
@@ -190,21 +191,24 @@ def reshape_image_to_4d_superpixel(img, dimensions):
            [2, 0, 4],
            [1, 2, 2]])
 
-
-
     Parameters
     ----------
     img : `numpy.ndarray`
-        A two-dimensional `~numpy.ndarray` of the form (y, x)
+        A two-dimensional `~numpy.ndarray` of the form (y, x).
 
     dimensions : array-like
         A two element array-like object containing integers that describe the
-        superpixel summation in the (y, x) directions
+        superpixel summation in the (y, x) directions.
+
+    offset : array-like
+        A two element array-like object containing integers that describe
+        where in the input image the array reshaping begins in the (y, x)
+        directions.
 
     Returns
     -------
     A four dimensional `~numpy.ndarray` that can be used to easily create
-    two-dimensional arrays of superpixels of the input image
+    two-dimensional arrays of superpixels of the input image.
 
     References
     ----------
@@ -212,17 +216,17 @@ def reshape_image_to_4d_superpixel(img, dimensions):
     http://mail.scipy.org/pipermail/numpy-discussion/2010-July/051760.html
 
     """
-    # check that the dimensions divide into the image size exactly
+    # make sure the input dimensions are integers
+    dimensions = [int(dim) for dim in dimensions]
 
-    if np.any(np.array(img.shape) % np.array(dimensions)):
-        raise ValueError('New dimensions must divide original image size exactly.')
+    # New dimensions of the final image
+    na = int(np.floor((img.shape[0] - offset[0]) / dimensions[0]))
+    nb = int(np.floor((img.shape[1] - offset[1]) / dimensions[1]))
 
     # Reshape up to a higher dimensional array which is useful for higher
     # level operations
-    return img.reshape(img.shape[0] / dimensions[0],
-                       dimensions[0],
-                       img.shape[1] / dimensions[1],
-                       dimensions[1])
+    return (img[offset[0]:offset[0] + na*dimensions[0],
+                offset[1]:offset[1] + nb*dimensions[1]]).reshape(na, dimensions[0], nb, dimensions[1])
 
 
 class UnrecognizedInterpolationMethod(ValueError):
