@@ -1,3 +1,4 @@
+from __future__ import absolute_import, division, print_function
 # Author: Jack Ireland, Steven Christe
 #
 # Testing functions for a mapcube coalignment functionality.  This
@@ -18,6 +19,7 @@ from sunpy.image.coalignment import parabolic_turning_point, \
     match_template_to_layer, clip_edges, \
     calculate_match_template_shift, mapcube_coalign_by_match_template,\
     apply_shifts
+from sunpy.extern.six.moves import range
 
 @pytest.fixture
 def aia171_test_clipping():
@@ -312,3 +314,16 @@ def test_apply_shifts(aia171_test_map):
         clipped = calculate_clipping(astropy_displacements["y"], astropy_displacements["x"])
         assert(test_mc[i].data.shape[0] == mc[i].data.shape[0] - np.max(clipped[0].value))
         assert(test_mc[i].data.shape[1] == mc[i].data.shape[1] - np.max(clipped[1].value))
+
+    # Test that keywords are correctly passed
+    # Test for an individual keyword
+    test_mc = apply_shifts(mc, astropy_displacements["y"], astropy_displacements["x"], clip=False,
+                           cval=np.nan)
+    assert(np.all(np.logical_not(np.isfinite(test_mc[1].data[:, -1]))))
+
+    # Test for a combination of keywords, and that changing the interpolation
+    # order and how the edges are treated changes the results.
+    test_mc1 = apply_shifts(mc, astropy_displacements["y"], astropy_displacements["x"], clip=False,
+                            order=2, mode='reflect')
+    test_mc2 = apply_shifts(mc, astropy_displacements["y"], astropy_displacements["x"], clip=False)
+    assert(np.all(test_mc1[1].data[:, -1] != test_mc2[1].data[:, -1]))
