@@ -1,11 +1,10 @@
-from __future__ import absolute_import, division
+from __future__ import absolute_import, division, print_function
 
 import os.path
 import datetime
 from warnings import warn
 import copy
 import csv
-import urllib
 import sqlite3
 
 import numpy as np
@@ -17,6 +16,8 @@ from sunpy import config
 from sunpy.util.net import check_download_file
 from sunpy import lightcurve
 
+from sunpy.extern.six.moves import urllib
+
 LYTAF_REMOTE_PATH = "http://proba2.oma.be/lyra/data/lytaf/"
 LYTAF_PATH = config.get("downloads", "download_dir")
 
@@ -234,7 +235,7 @@ def _remove_lytaf_events(time, channels=None, artifacts=None,
                                                   print_event_types=False)
     for artifact in artifacts:
         if artifact not in all_lytaf_event_types:
-            print all_lytaf_event_types
+            print(all_lytaf_event_types)
             raise ValueError("{0} is not a valid artifact type. See above.".format(artifact))
     # Define outputs
     clean_time = np.array([parse_time(t) for t in time])
@@ -543,7 +544,7 @@ def get_lytaf_event_types(lytaf_path=None, print_event_types=True):
     all_event_types = []
     # For each database file extract the event types and print them.
     if print_event_types:
-        print "\nLYTAF Event Types\n-----------------\n"
+        print("\nLYTAF Event Types\n-----------------\n")
     for suffix in suffixes:
         dbname = "annotation_{0}.db".format(suffix)
         # Check database file exists, else download it.
@@ -556,23 +557,26 @@ def get_lytaf_event_types(lytaf_path=None, print_event_types=True):
         event_types = cursor.fetchall()
         all_event_types.append(event_types)
         if print_event_types:
-            print "----------------\n{0} database\n----------------".format(suffix)
+            print("----------------\n{0} database\n----------------"
+                  .format(suffix))
             for event_type in event_types:
-                print str(event_type[0])
-            print " "
+                print(str(event_type[0]))
+            print(" ")
     # Unpack event types in all_event_types into single list
     all_event_types = [event_type[0] for event_types in all_event_types
                        for event_type in event_types]
     return all_event_types
 
+
 def download_lytaf_database(lytaf_dir=''):
     """download latest Proba2 pointing database from Proba2 Science Center"""
     url = 'http://proba2.oma.be/lyra/data/lytaf/annotation_ppt.db'
     destination = os.path.join(lytaf_dir, 'annotation_ppt.db')
-    urllib.urlretrieve(url, destination)
+    urllib.request.urlretrieve(url, destination)
 
     return
 
+
 def split_series_using_lytaf(timearray, data, lytaf):
     """
     Proba-2 analysis code for splitting up LYRA timeseries around locations
@@ -621,9 +625,9 @@ def split_series_using_lytaf(timearray, data, lytaf):
     disc = tmp_discontinuity[0]
 
     if len(disc) == 0:
-        print 'No events found within time series interval. '\
-          +'Returning original series.'
-        return [{'subtimes':datetime_array, 'subdata':data}]
+        print('No events found within time series interval. '
+              'Returning original series.')
+        return [{'subtimes': datetime_array, 'subdata': data}]
 
     # -1 in diffmask means went from good data to bad
     # +1 means went from bad data to good
