@@ -2,13 +2,11 @@
 """
     Provides programs to process and analyze RHESSI data.
 
-    .. warning:: This module is still in development!
+    .. warning:: This module is in development.
 
 """
+from __future__ import absolute_import, print_function
 
-from __future__ import absolute_import
-
-import urllib
 import csv
 from datetime import datetime
 from datetime import timedelta
@@ -25,6 +23,8 @@ from sunpy.time import TimeRange, parse_time
 from sunpy.sun.sun import solar_semidiameter_angular_size
 from sunpy.sun.sun import sunearth_distance
 
+from sunpy.extern.six.moves import urllib
+
 __all__ = ['get_obssumm_dbase_file', 'parse_obssumm_dbase_file',
            'get_obssum_filename', 'get_obssumm_file', 'parse_obssumm_file',
            'backprojection']
@@ -82,7 +82,7 @@ def get_obssumm_dbase_file(time_range):
     url_root = data_servers[0] + data_location
     url = url_root + _time_range.start.strftime("hsi_obssumm_filedb_%Y%m.txt")
 
-    f = urllib.urlretrieve(url)
+    f = urllib.request.urlretrieve(url)
 
     return f
 
@@ -117,12 +117,12 @@ def parse_obssumm_dbase_file(filename):
         This API is currently limited to providing data from whole days only.
 
     """
-    with open(filename, "rb") as fd:
+    with open(filename, "rt") as fd:
         reader = csv.reader(fd, delimiter=' ', skipinitialspace=True)
-        headerline = reader.next()
-        headerline = reader.next()
-        headerline = reader.next()
-        headerline = reader.next()
+        headerline = next(reader)
+        headerline = next(reader)
+        headerline = next(reader)
+        headerline = next(reader)
 
         obssumm_filename = []
         orbit_start = []
@@ -226,7 +226,7 @@ def get_obssumm_file(time_range):
     url = url_root + get_obssum_filename(time_range)
 
     print('Downloading file: ' + url)
-    f = urllib.urlretrieve(url)
+    f = urllib.request.urlretrieve(url)
 
     return f
 
@@ -365,7 +365,7 @@ def _backproject(calibrated_event_list, detector=8, pixel_size=(1., 1.),
     tempa = (np.arange(image_dim[0]*image_dim[1]) %  image_dim[0]) - (image_dim[0]-1)/2.
     tempb = tempa.reshape(image_dim[0],image_dim[1]).transpose().reshape(image_dim[0]*image_dim[1])
 
-    pixel = np.array(zip(tempa,tempb))*pixel_size[0]
+    pixel = np.array(list(zip(tempa,tempb)))*pixel_size[0]
     phase_pixel = (2*np.pi/harm_ang_pitch)* ( np.outer(pixel[:,0], np.cos(this_roll_angle - grid_angle)) -
                                               np.outer(pixel[:,1], np.sin(this_roll_angle - grid_angle))) + phase_map_center
     phase_modulation = np.cos(phase_pixel)
