@@ -30,6 +30,7 @@ References
 | http://stsdas.stsci.edu/download/wikidocs/The_PyFITS_Handbook.pdf
 
 """
+from __future__ import absolute_import, division, print_function
 import os
 import re
 import itertools
@@ -38,13 +39,14 @@ import collections
 from astropy.io import fits
 
 from sunpy.io.header import FileHeader
+from sunpy.extern.six.moves import zip
 
 __all__ = ['read', 'get_header', 'write', 'extract_waveunit']
 
 __author__ = "Keith Hughitt, Stuart Mumford, Simon Liedtke"
 __email__ = "keith.hughitt@nasa.gov"
 
-def read(filepath, hdus=None):
+def read(filepath, hdus=None, memmap=None, **kwargs):
     """
     Read a fits file
 
@@ -67,7 +69,7 @@ def read(filepath, hdus=None):
     Also all comments in the original file are concatenated into a single
     'comment' key in the returned FileHeader.
     """
-    hdulist = fits.open(filepath)
+    hdulist = fits.open(filepath, memmap=memmap)
     if hdus is not None:
         if isinstance(hdus, int):
             hdulist = hdulist[hdus]
@@ -78,7 +80,7 @@ def read(filepath, hdus=None):
 
         headers = get_header(hdulist)
         pairs = []
-        for hdu,header in itertools.izip(hdulist, headers):
+        for hdu,header in zip(hdulist, headers):
             pairs.append((hdu.data, header))
     finally:
         hdulist.close()
