@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 """Provides programs to process and analyze PROBA2/LYRA data."""
-from __future__ import absolute_import
+from __future__ import absolute_import, division, print_function
 
 import datetime
-import urlparse
 import sys
 from collections import OrderedDict
 
@@ -15,6 +14,9 @@ from sunpy.lightcurve import LightCurve
 from sunpy.time import parse_time
 
 from sunpy import config
+
+from sunpy.extern.six.moves import urllib
+
 TIME_FORMAT = config.get("general", "time_format")
 
 __all__ = ['LYRALightCurve']
@@ -38,12 +40,18 @@ class LYRALightCurve(LightCurve):
 
     PROBA2 was launched on 2 November 2009.
 
+    This class can download and hold either Level 2 data (the default) which
+    has sub-second resolution or Level 3 which is the Level 2 data averaged to
+    one minute cadence. The level can be specified with the ``level`` keyword
+    argument to `~sunpy.lightcurve.LyraLightCurve.create`.
+
     Examples
     --------
     >>> import sunpy
     >>> lyra = sunpy.lightcurve.LYRALightCurve.create()
     >>> lyra = sunpy.lightcurve.LYRALightCurve.create('~/Data/lyra/lyra_20110810-000000_lev2_std.fits')   # doctest: +SKIP
     >>> lyra = sunpy.lightcurve.LYRALightCurve.create('2011/08/10')
+    >>> lyra = sunpy.lightcurve.LYRALightCurve.create('2011/08/10', level=3)
     >>> lyra = sunpy.lightcurve.LYRALightCurve.create("http://proba2.oma.be/lyra/data/bsd/2011/08/10/lyra_20110810-000000_lev2_std.fits")
     >>> lyra.peek()   # doctest: +SKIP
 
@@ -114,17 +122,17 @@ class LYRALightCurve(LightCurve):
         return figure
 
     @staticmethod
-    def _get_url_for_date(date,**kwargs):
+    def _get_url_for_date(date, **kwargs):
         """Returns a URL to the LYRA data for the specified date"""
         dt = parse_time(date or datetime.datetime.utcnow())
 
         # Filename
         filename = "lyra_{0:%Y%m%d-}000000_lev{1:d}_std.fits".format(
-            dt, kwargs.get('level',2))
+            dt, kwargs.get('level', 2))
         # URL
         base_url = "http://proba2.oma.be/lyra/data/bsd/"
-        url_path = urlparse.urljoin(dt.strftime('%Y/%m/%d/'), filename)
-        return urlparse.urljoin(base_url, url_path)
+        url_path = urllib.parse.urljoin(dt.strftime('%Y/%m/%d/'), filename)
+        return urllib.parse.urljoin(base_url, url_path)
 
     @classmethod
     def _get_default_uri(cls):
@@ -175,5 +183,5 @@ class LYRALightCurve(LightCurve):
 
         # Return the header and the data
         data = pandas.DataFrame(table, index=times)
-        data.sort(inplace=True)
+        data.sort_index(inplace=True)
         return OrderedDict(hdulist[0].header), data
