@@ -2,7 +2,7 @@
 
 Author: `Keith Hughitt <keith.hughitt@nasa.gov>`
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, division
 
 import matplotlib.pyplot as plt
 
@@ -11,6 +11,8 @@ import astropy.units as u
 from sunpy.map import GenericMap
 
 from sunpy.util import expand_list
+from sunpy.extern import six
+from sunpy.extern.six.moves import range
 
 __all__ = ['CompositeMap']
 
@@ -85,7 +87,7 @@ class CompositeMap(object):
 
         # Default alpha and zorder values
         alphas = [1] * len(self._maps)
-        zorders = range(0, 10 * len(self._maps), 10)
+        zorders = list(range(0, 10 * len(self._maps), 10))
         levels = [False] * len(self._maps)
 
         # Set z-order and alpha values for the map
@@ -138,7 +140,7 @@ class CompositeMap(object):
 
     def list_maps(self):
         """Prints a list of the currently included maps."""
-        print [m.__class__ for m in self._maps]
+        print([m.__class__ for m in self._maps])
 
     def get_map(self, index):
         """Returns the map with given index """
@@ -431,15 +433,15 @@ class CompositeMap(object):
         if annotate:
             # x-axis label
             if self._maps[0].coordinate_system.x == 'HG':
-                xlabel = 'Longitude [{lon}]'.format(lon=self._maps[0].units.x)
+                xlabel = 'Longitude [{lon}]'.format(lon=self._maps[0].spatial_units.x)
             else:
-                xlabel = 'X-position [{solx}]'.format(solx=self._maps[0].units.x)
+                xlabel = 'X-position [{solx}]'.format(solx=self._maps[0].spatial_units.x)
 
             # y-axis label
             if self._maps[0].coordinate_system.y == 'HG':
-                ylabel = 'Latitude [{lat}]'.format(lat=self._maps[0].units.y)
+                ylabel = 'Latitude [{lat}]'.format(lat=self._maps[0].spatial_units.y)
             else:
-                ylabel = 'Y-position [{soly}]'.format(soly=self._maps[0].units.y)
+                ylabel = 'Y-position [{soly}]'.format(soly=self._maps[0].spatial_units.y)
 
             axes.set_xlabel(xlabel)
             axes.set_ylabel(ylabel)
@@ -523,7 +525,7 @@ class CompositeMap(object):
             if draw_grid:
                 self.draw_grid(axes=axes)
 
-        elif isinstance(draw_grid, (int, long, float)):
+        elif isinstance(draw_grid, six.integer_types + (float,)):
             self.draw_grid(axes=axes, grid_spacing=draw_grid)
         else:
             raise TypeError("draw_grid should be bool, int, long or float")
