@@ -5,14 +5,13 @@ __email__ = "stuart@mumford.me.uk"
 
 import os
 import glob
-import urllib2
 from collections import OrderedDict
 
 import numpy as np
 import astropy.io.fits
 
 import sunpy
-from sunpy.map import GenericMap
+from sunpy.map.mapbase import GenericMap, MAP_CLASSES
 from sunpy.map.header import MapMeta
 from sunpy.map.compositemap import CompositeMap
 from sunpy.map.mapcube import MapCube
@@ -27,6 +26,9 @@ from sunpy.util.datatype_factory_base import BasicRegistrationFactory
 from sunpy.util.datatype_factory_base import NoMatchError
 from sunpy.util.datatype_factory_base import MultipleMatchError
 from sunpy.util.datatype_factory_base import ValidationFunctionError
+from sunpy.extern import six
+
+from sunpy.extern.six.moves.urllib.request import urlopen
 
 # Make a mock DatabaseEntry class if sqlalchemy is not installed
 
@@ -177,14 +179,14 @@ class MapFactory(BasicRegistrationFactory):
                 i += 1 # an extra increment to account for the data-header pairing
 
             # File name
-            elif (isinstance(arg,basestring) and
+            elif (isinstance(arg,six.string_types) and
                   os.path.isfile(os.path.expanduser(arg))):
                 path = os.path.expanduser(arg)
                 pairs = self._read_file(path, **kwargs)
                 data_header_pairs += pairs
 
             # Directory
-            elif (isinstance(arg,basestring) and
+            elif (isinstance(arg,six.string_types) and
                   os.path.isdir(os.path.expanduser(arg))):
                 path = os.path.expanduser(arg)
                 files = [os.path.join(path, elem) for elem in os.listdir(path)]
@@ -192,7 +194,7 @@ class MapFactory(BasicRegistrationFactory):
                     data_header_pairs += self._read_file(afile, **kwargs)
 
             # Glob
-            elif (isinstance(arg,basestring) and '*' in arg):
+            elif (isinstance(arg,six.string_types) and '*' in arg):
                 files = glob.glob( os.path.expanduser(arg) )
                 for afile in files:
                     data_header_pairs += self._read_file(afile, **kwargs)
@@ -202,7 +204,7 @@ class MapFactory(BasicRegistrationFactory):
                 already_maps.append(arg)
 
             # A URL
-            elif (isinstance(arg,basestring) and
+            elif (isinstance(arg,six.string_types) and
                   _is_url(arg)):
                 default_dir = sunpy.config.get("downloads", "download_dir")
                 url = arg
@@ -245,6 +247,10 @@ class MapFactory(BasicRegistrationFactory):
         silence_errors : boolean, optional
             If set, ignore data-header pairs which cause an exception.
 
+        Notes
+        -----
+        Extra keyword arguments are passed through to `sunpy.io.read_file` such
+        as `memmap` for FITS files.
         """
 
         # Hack to get around Python 2.x not backporting PEP 3102.
@@ -315,7 +321,7 @@ class MapFactory(BasicRegistrationFactory):
 
 def _is_url(arg):
     try:
-        urllib2.urlopen(arg)
+        urlopen(arg)
     except:
         return False
     return True
@@ -337,3 +343,4 @@ class NoMapsFound(ValueError):
 
 Map = MapFactory(default_widget_type=GenericMap,
                  additional_validation_functions=['is_datasource_for'])
+Map.registry = MAP_CLASSES
