@@ -8,8 +8,9 @@ import numpy as np
 import matplotlib.animation
 import numpy.ma as ma
 
-from sunpy.map import GenericMap
+import astropy.units as u
 
+from sunpy.map import GenericMap
 from sunpy.visualization.mapcubeanimator import MapCubeAnimator
 from sunpy.visualization import wcsaxes_compat
 from sunpy.util import expand_list
@@ -61,7 +62,7 @@ class MapCube(object):
         for m in self.maps:
             if not isinstance(m, GenericMap):
                 raise ValueError(
-                           'CompositeMap expects pre-constructed map objects.')
+                           'MapCube expects pre-constructed map objects.')
 
         # Optionally sort data
         if sortby is not None:
@@ -192,10 +193,11 @@ class MapCube(object):
             axes.set_ylabel(ylabel)
 
         if resample:
-            # This assumes that the maps are homogeneous!
-            # TODO: Update this!
-            resample = np.array(len(self.maps)-1) * np.array(resample)
-            ani_data = [x.resample(resample) for x in self.maps]
+            if self.all_maps_same_shape():
+                resample = u.Quantity(self.maps[0].dimensions) * np.array(resample)
+                ani_data = [amap.resample(resample) for amap in self.maps]
+            else:
+                raise ValueError('Maps in mapcube do not all have the same shape.')
         else:
             ani_data = self.maps
 
@@ -206,29 +208,30 @@ class MapCube(object):
                 removes.pop(0).remove()
 
             im.set_array(ani_data[i].data)
-            im.set_cmap(self.maps[i].plot_settings['cmap'])
+            im.set_cmap(ani_data[i].plot_settings['cmap'])
 
-            norm = deepcopy(self.maps[i].plot_settings['norm'])
-            # The following explicit call is for bugged versions of Astropy's ImageNormalize
+            norm = deepcopy(ani_data[i].plot_settings['norm'])
+            # The following explicit call is for bugged versions of Astropy's
+            # ImageNormalize
             norm.autoscale_None(ani_data[i].data)
             im.set_norm(norm)
 
             if wcsaxes_compat.is_wcsaxes(axes):
-                im.axes.reset_wcs(self.maps[i].wcs)
+                im.axes.reset_wcs(ani_data[i].wcs)
                 wcsaxes_compat.default_wcs_grid(axes)
             else:
-                im.set_extent(np.concatenate((self.maps[i].xrange.value,
-                                              self.maps[i].yrange.value)))
+                im.set_extent(np.concatenate((ani_data[i].xrange.value,
+                                              ani_data[i].yrange.value)))
 
             if annotate:
                 annotate_frame(i)
-            removes += list(plot_function(fig, axes, self.maps[i]))
+            removes += list(plot_function(fig, axes, ani_data[i]))
 
         ani = matplotlib.animation.FuncAnimation(fig, updatefig,
-                                                frames=list(range(0, len(self.maps))),
-                                                fargs=[im, annotate, ani_data, removes],
-                                                interval=interval,
-                                                blit=False)
+                                                 frames=list(range(0, len(ani_data))),
+                                                 fargs=[im, annotate, ani_data, removes],
+                                                 interval=interval,
+                                                 blit=False)
 
         return ani
 
@@ -303,13 +306,16 @@ class MapCube(object):
 
         if resample:
             if self.all_maps_same_shape():
-                resample = np.array(len(self.maps) - 1) * np.array(resample)
+                plot_cube = MapCube()
+                resample = u.Quantity(self.maps[0].dimensions) * np.array(resample)
                 for amap in self.maps:
-                    amap.resample(resample)
+                    plot_cube.maps.append(amap.resample(resample))
             else:
                 raise ValueError('Maps in mapcube do not all have the same shape.')
+        else:
+            plot_cube = self
 
-        return MapCubeAnimator(self, **kwargs)
+        return MapCubeAnimator(plot_cube, **kwargs)
 
     def all_maps_same_shape(self):
         """
