@@ -14,7 +14,7 @@ class TestMapMeta(object):
         #get
         assert meta.get('wibble') == meta.get('WIBBLE')
         #has_key
-        assert meta.has_key('wibble') == meta.has_key('WIBBLE')
+        assert ('wibble' in meta) == ('WIBBLE' in meta)
         #Copy
         meta2 = meta.copy()
         assert meta2 == meta
