@@ -2,16 +2,11 @@
 # Author: Florian Mayer <florian.mayer@bitsrc.org>
 
 """Classes for spectral analysis."""
-
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import division, print_function, absolute_import
 
 import datetime
 
 from random import randint
-from itertools import izip
 from copy import copy
 from math import floor
 
@@ -25,13 +20,12 @@ from matplotlib.figure import Figure
 from matplotlib.ticker import FuncFormatter, MaxNLocator, IndexLocator
 from matplotlib.colorbar import Colorbar
 
-#import sunpy
-
 from sunpy.time import parse_time, get_day
 from sunpy.util import to_signed, common_base, merge
 from sunpy.util.cond_dispatch import ConditionalDispatch
 from sunpy.util.create import Parent
 from sunpy.spectra.spectrum import Spectrum
+from sunpy.extern.six.moves import zip, range
 
 __all__ = ['Spectrogram', 'LinearTimeSpectrogram']
 
@@ -49,6 +43,7 @@ REFERENCE = 0
 COPY = 1
 DEEPCOPY = 2
 
+
 def figure(*args, **kwargs):
     """Returns a new SpectroFigure, a figure extended with features
     useful for analysis of spectrograms. Compare pyplot.figure."""
@@ -65,6 +60,7 @@ def _min_delt(arr):
     # in the process of linearizaion
     return deltas[deltas != 0].min()
 
+
 def _list_formatter(lst, fun=None):
     """Returns a function that takes x, pos and returns fun(lst[x]) if
     fun is not None, else lst[x] or "" if x is out of range. """
@@ -120,7 +116,8 @@ class _LinearView(object):
         self.shape = (len(self), arr.data.shape[1])
 
     def __len__(self):
-        return 1 + (self.arr.freq_axis[0] - self.arr.freq_axis[-1]) / self.delt
+        return int(1 + (self.arr.freq_axis[0] - self.arr.freq_axis[-1]) /
+                   self.delt)
 
     def _find(self, arr, item):
         if item < 0:
@@ -133,7 +130,7 @@ class _LinearView(object):
         # The idea is that when we take the biggest delta in the mid points,
         # we do not have to search anything that is between the beginning and
         # the first item that can possibly be that frequency.
-        min_mid = max(0, (freq - self.midpoints[0]) // self.max_mp_delt)
+        min_mid = int(max(0, (freq - self.midpoints[0]) // self.max_mp_delt))
         for n, mid in enumerate(self.midpoints[min_mid:]):
             if mid <= freq:
                 return arr[min_mid + n]
@@ -147,7 +144,7 @@ class _LinearView(object):
 
     def make_mask(self, max_dist):
         mask = np.zeros(self.shape, dtype=np.bool)
-        for n, item in enumerate(xrange(len(self))):
+        for n, item in enumerate(range(len(self))):
             freq = self.arr.freq_axis[0] - item * self.delt
             if abs(self.get_freq(item) - freq) > max_dist:
                 mask[n, :] = True
@@ -223,6 +220,7 @@ class TimeFreq(object):
         axes = figure.add_subplot(111)
         axes.plot(self.time, self.freq, **kwargs)
         xa = axes.get_xaxis()
+        # FIXME: ``ya`` is not used?
         ya = axes.get_yaxis()
         xa.set_major_formatter(
             FuncFormatter(
@@ -340,12 +338,15 @@ class Spectrogram(Parent):
         params = self._get_params()
 
         soffset = 0 if x_range.start is None else x_range.start
-        eoffset = self.shape[1] if x_range.stop is None else x_range.stop # pylint: disable=E1101
+        soffset = int(soffset)
+        eoffset = self.shape[1] if x_range.stop is None else x_range.stop  # pylint: disable=E1101
         eoffset -= 1
+        eoffset = int(eoffset)
 
         # FIXME: `fsoffset` and `feoffset` are not used?!
         fsoffset = 0 if y_range.start is None else y_range.start
-        feoffset = self.shape[0] if y_range.stop is None else y_range.stop # pylint: disable=E1101
+        feoffset = self.shape[0] if y_range.stop is None else y_range.stop  # pylint: disable=E1101
+        feoffset = int(feoffset)
 
         params.update({
             'time_axis': self.time_axis[
@@ -367,7 +368,8 @@ class Spectrogram(Parent):
         return new
 
     def __init__(self, data, time_axis, freq_axis, start, end, t_init=None,
-        t_label="Time", f_label="Frequency", content="", instruments=None):
+                 t_label="Time", f_label="Frequency", content="",
+                 instruments=None):
         # Because of how object creation works, there is no avoiding
         # unused arguments in this case.
         self.data = data
@@ -438,8 +440,8 @@ class Spectrogram(Parent):
         plt.show()
         return ret
 
-    def plot(self, figure=None, overlays=[], colorbar=True, vmin=None, vmax=None,
-             linear=True, showz=True, yres=DEFAULT_YRES,
+    def plot(self, figure=None, overlays=[], colorbar=True, vmin=None,
+             vmax=None, linear=True, showz=True, yres=DEFAULT_YRES,
              max_dist=None, **matplotlib_args):
         """
         Plot spectrogram onto figure.
@@ -596,7 +598,7 @@ class Spectrogram(Parent):
         only_y = not isinstance(key, tuple)
 
         if only_y:
-            return self.data[key]
+            return self.data[int(key)]
         elif isinstance(key[0], slice) and isinstance(key[1], slice):
             return self._slice(key[0], key[1])
         elif isinstance(key[1], slice):
@@ -611,7 +613,7 @@ class Spectrogram(Parent):
                 self.freq_axis[key[0].start:key[0].stop:key[0].step]
             )
 
-        return self.data[key]
+        return self.data[int(key)]
 
     def clip_freq(self, vmin=None, vmax=None):
         """Return a new spectrogram only consisting of frequencies
@@ -645,7 +647,8 @@ class Spectrogram(Parent):
         Parameters
         ----------
         amount : float
-            The percent amount (out of 1) of lowest standard deviation to consider.
+            The percent amount (out of 1) of lowest standard deviation to
+            consider.
         """
         # pylint: disable=E1101,E1103
         data = self.data.astype(to_signed(self.dtype))
@@ -657,7 +660,7 @@ class Spectrogram(Parent):
         sdevs = np.asarray(np.std(tmp, 0))
 
         # Get indices of values with lowest standard deviation.
-        cand = sorted(xrange(self.shape[1]), key=lambda y: sdevs[y])
+        cand = sorted(range(self.shape[1]), key=lambda y: sdevs[y])
         # Only consider the best 5 %.
         return cand[:max(1, int(amount * len(cand)))]
 
@@ -681,7 +684,7 @@ class Spectrogram(Parent):
             Size of random sample that is considered for calculation of
             the background.
         """
-        cols = [randint(0, self.shape[1] - 1) for _ in xrange(amount)]
+        cols = [randint(0, self.shape[1] - 1) for _ in range(amount)]
 
         # pylint: disable=E1101,E1103
         data = self.data.astype(to_signed(self.dtype))
@@ -694,7 +697,7 @@ class Spectrogram(Parent):
         sdevs = np.asarray(np.std(tmp, 0))
 
         # Get indices of values with lowest standard deviation.
-        cand = sorted(xrange(amount), key=lambda y: sdevs[y])
+        cand = sorted(range(amount), key=lambda y: sdevs[y])
         # Only consider the best 5 %.
         realcand = cand[:max(1, int(0.05 * len(cand)))]
 
@@ -740,7 +743,7 @@ class Spectrogram(Parent):
         return self._with_data(self.data.clip(vmin, vmax, out))
 
     def rescale(self, vmin=0, vmax=1, dtype=np.dtype('float32')):
-        u"""
+        """
         Rescale intensities to [vmin, vmax].
         Note that vmin ≠ vmax and spectrogram.min() ≠ spectrogram.max().
 
@@ -775,7 +778,7 @@ class Spectrogram(Parent):
             freq_axis[0] >= frequency >= self_freq_axis[-1]
         """
         lfreq, lvalue = None, None
-        for freq, value in izip(self.freq_axis, self.data[:, :]):
+        for freq, value in zip(self.freq_axis, self.data[:, :]):
             if freq < frequency:
                 break
             lfreq, lvalue = freq, value
@@ -817,7 +820,7 @@ class Spectrogram(Parent):
         fillto = np.abs(fillto)
         fillfrom = np.abs(fillfrom)
 
-        for row, from_, to_ in izip(self, fillfrom, fillto):
+        for row, from_, to_ in zip(self, fillfrom, fillto):
             new[from_: to_] = row
 
         vrs = self._get_params()
@@ -869,7 +872,7 @@ class Spectrogram(Parent):
     @staticmethod
     def _mk_format_coord(spec, fmt_coord):
         def format_coord(x, y):
-            shape = map(int, spec.shape)
+            shape = list(map(int, spec.shape))
 
             xint, yint = int(x), int(y)
             if 0 <= xint < shape[1] and 0 <= yint < shape[0]:
@@ -1050,7 +1053,7 @@ class LinearTimeSpectrogram(Spectrogram):
         # Amount of pixels left out due to non-linearity. Needs to be
         # considered for correct time axes.
         sd = 0
-        for x, elem in izip(xs, specs):
+        for x, elem in zip(xs, specs):
             diff = x - elem.shape[1]
             e_time_axis = elem.time_axis
 
@@ -1170,17 +1173,16 @@ class LinearTimeSpectrogram(Spectrogram):
 
         freq_axis = np.zeros((fsize,))
 
-
         for n, (data, row) in enumerate(merge(
             [
-                [(sp, n) for n in xrange(sp.shape[0])] for sp in specs
+                [(sp, n) for n in range(sp.shape[0])] for sp in specs
             ],
             key=lambda x: x[0].freq_axis[x[1]]
         )):
             new[n, :] = data[row, :]
             freq_axis[n] = data.freq_axis[row]
         params = {
-            'time_axis': one.time_axis, # Should be equal
+            'time_axis': one.time_axis,  # Should be equal
             'freq_axis': freq_axis,
             'start': one.start,
             'end': one.end,
@@ -1242,7 +1244,7 @@ class LinearTimeSpectrogram(Spectrogram):
                     )
                 start = datetime.datetime(
                     self.start.year, self.start.month, self.start.day,
-                    *map(int, start.split(":"))
+                    *list(map(int, start.split(":")))
                 )
             start = self.time_to_x(start)
         if end is not None:
@@ -1255,7 +1257,7 @@ class LinearTimeSpectrogram(Spectrogram):
                     )
                 end = datetime.datetime(
                     self.start.year, self.start.month, self.start.day,
-                    *map(int, end.split(":"))
+                    *list(map(int, end.split(":")))
                 )
             end = self.time_to_x(end)
         return self[:, start:end]
