@@ -7,10 +7,11 @@ Created on Sat Jun  7 19:36:08 2014
 This file is designed to be imported and ran only via setup.py, hence it's
 dependency on astropy_helpers which will be available in that context.
 """
+from __future__ import absolute_import, division, print_function
 
 import os
 
-from astropy_helpers.test_helpers import AstropyTest
+from astropy_helpers.commands.test import AstropyTest
 from astropy_helpers.compat import _fix_user_options
 
 
@@ -29,7 +30,7 @@ class SunPyTest(AstropyTest):
         ('plugins=', 'p',
          'Plugins to enable when running pytest.'),
         # Run online tests?
-        ('online', None,
+        ('online', 'R',
          'Also run tests that do require a internet connection.'),
         # Run only online tests?
         ('online-only', None,
