@@ -1,8 +1,6 @@
 """SunPy utility functions"""
-from __future__ import absolute_import
+from __future__ import absolute_import, division, print_function
 
 from sunpy.util.util import *
 from sunpy.util.sysinfo import *
 
-import astropy.units
-
