@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Author: Florian Mayer <florian.mayer@bitsrc.org>
 
-from __future__ import absolute_import
+from __future__ import absolute_import, division, print_function
 
 import os
 import glob
@@ -10,6 +10,8 @@ from sunpy import config
 from sunpy.util.net import download_file
 
 from sunpy.util.cond_dispatch import ConditionalDispatch, run_cls
+from sunpy.extern import six
+from sunpy.extern.six.moves import map
 
 __all__ = ['Parent']
 
@@ -22,7 +24,7 @@ class Parent(object):
 
     @classmethod
     def read_many(cls, filenames):
-        return map(cls.read, filenames)
+        return list(map(cls.read, filenames))
 
     @classmethod
     def from_glob(cls, pattern):
@@ -45,7 +47,7 @@ class Parent(object):
     def from_files(cls, filenames):
         """ Return list of object read from given list of
         filenames. """
-        filenames = map(os.path.expanduser, filenames)
+        filenames = list(map(os.path.expanduser, filenames))
         return cls.read_many(filenames)
 
     @classmethod
@@ -79,7 +81,7 @@ class Parent(object):
 Parent._create.add(
     run_cls('from_file'),
     lambda cls, filename: os.path.isfile(os.path.expanduser(filename)),
-    [type, basestring], check=False
+    [type, six.string_types], check=False
 )
 Parent._create.add(
 # pylint: disable=W0108
@@ -87,7 +89,7 @@ Parent._create.add(
 # argspec of the function.
     run_cls('from_dir'),
     lambda cls, directory: os.path.isdir(os.path.expanduser(directory)),
-    [type, basestring], check=False
+    [type, six.string_types], check=False
 )
 # If it is not a kwarg and only one matches, do not return a list.
 Parent._create.add(
@@ -95,7 +97,7 @@ Parent._create.add(
     lambda cls, singlepattern: ('*' in singlepattern and
                            len(glob.glob(
                                os.path.expanduser(singlepattern))) == 1),
-    [type, basestring], check=False
+    [type, six.string_types], check=False
 )
 # This case only gets executed under the condition that the previous one wasn't.
 # This is either because more than one file matched, or because the user
@@ -105,7 +107,7 @@ Parent._create.add(
     lambda cls, pattern: '*' in pattern and glob.glob(
         os.path.expanduser(pattern)
         ),
-    [type, basestring], check=False
+    [type, six.string_types], check=False
 )
 Parent._create.add(
     run_cls('from_files'),
@@ -115,5 +117,5 @@ Parent._create.add(
 Parent._create.add(
     run_cls('from_url'),
     lambda cls, url: True,
-    types=[type, basestring], check=False
+    types=[type, six.string_types], check=False
 )
