@@ -1,24 +1,23 @@
 # -*- coding: utf-8 -*-
 # Author: Florian Mayer <florian.mayer@bitsrc.org>
 
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
+from __future__ import absolute_import, division, print_function
 import os
 import re
 import sys
 import shutil
 
 # For Content-Disposition parsing
-import urllib2
-import urlparse
+from sunpy.extern.six.moves.urllib.parse import urlparse, urljoin
+from sunpy.extern.six.moves.urllib.request import urlopen
+from sunpy.extern.six.moves.urllib.error import HTTPError, URLError
+from sunpy.extern.six.moves import filter
+
 from email.parser import FeedParser
 from unicodedata import normalize
-from itertools import ifilter
 
 from sunpy.util import replacement_filename
+from sunpy.extern import six
 
 __all__ = ['slugify', 'get_content_disposition', 'get_filename',
            'get_system_filename', 'get_system_filename_slugify',
@@ -38,14 +37,12 @@ def slugify(text, delim=u'_', encoding="ascii"):
     name_and_extension = text.rsplit(period, 1)
     name = name_and_extension[0]
 
-    name = unicode(delim).join(ifilter(None, (
-        word.encode(encoding, 'ignore')
-        for word in _punct_re.split(name.lower())
-    )))
+    name = six.text_type(delim).join(
+        filter(None, (word for word in _punct_re.split(name.lower()))))
 
     if len(name_and_extension) == 2:
         extension = name_and_extension[1]
-        return unicode(period).join([name, extension])
+        return six.text_type(period).join([name, extension])
     else:
         return name
 
@@ -54,9 +51,9 @@ def get_content_disposition(content_disposition):
     """ Get content disposition filename from given header. Do not include
     "Content-Disposition:". Returns a unicode string! """
     parser = FeedParser()
-    parser.feed(b'Content-Disposition: ' + content_disposition)
+    parser.feed('Content-Disposition: ' + content_disposition)
     name = parser.close().get_filename()
-    if not isinstance(name, unicode):
+    if not isinstance(name, six.text_type):
         name = name.decode('latin1', 'ignore')
     return name
 
@@ -76,9 +73,9 @@ def get_filename(sock, url):
             pass
 
     if not name:
-        parsed = urlparse.urlparse(url)
+        parsed = urlparse(url)
         name = parsed.path.rstrip('/').rsplit('/', 1)[-1]
-    return unicode(name)
+    return six.text_type(name)
 
 
 def get_system_filename(sock, url, default=u"file"):
@@ -106,7 +103,7 @@ def download_file(url, directory, default=u'file', overwrite=False):
     Content-Disposition header, otherwise get from path of url. Fall
     back to default if both fail. Only overwrite existing files when
     overwrite is True. """
-    opn = urllib2.urlopen(url)
+    opn = urlopen(url)
     try:
         path = download_fileobj(opn, directory, url, default, overwrite)
     finally:
@@ -120,7 +117,7 @@ def download_fileobj(opn, directory, url='', default=u"file", overwrite=False):
     Fall back to default if both fail. Only overwrite existing files when
     overwrite is True. """
     filename = get_system_filename(opn, url, default)
-    path = os.path.join(directory, filename)
+    path = os.path.join(directory, filename.decode('utf-8'))
     if not overwrite and os.path.exists(path):
         path = replacement_filename(path)
     with open(path, 'wb') as fd:
@@ -166,10 +163,10 @@ def check_download_file(filename, remotepath, download_dir, remotename=None,
     if replace or not os.path.isfile(os.path.join(download_dir, filename)):
         # set local and remote file names be the same unless specified
         # by user.
-        if not isinstance(remotename, basestring):
+        if not isinstance(remotename, six.string_types):
             remotename = filename
 
-        download_file(urlparse.urljoin(remotepath, remotename),
+        download_file(urljoin(remotepath, remotename),
                       download_dir, default=filename, overwrite=replace)
 
 
@@ -195,10 +192,10 @@ def url_exists(url, timeout=2):
     False
     """
     try:
-        urllib2.urlopen(url, timeout=timeout)
-    except urllib2.HTTPError:
+        urlopen(url, timeout=timeout)
+    except HTTPError:
         return False
-    except urllib2.URLError:
+    except URLError:
         return False
     else:
         return True
